<?php
	class Dcom_Ads_Calc_Base extends WP_Widget {
		/* Pass through, try to disable */
		protected $program_options = array();

		// Draw Widgets
		public function widget( $args, $instance ) {
			echo $args['before_widget'];

			// Show Title if assigned
			if ( ! empty( $instance['title'] ) ) {
				echo $args['before_title'] . apply_filters( 'widget_title', $instance['title'] ) . $args['after_title'];
			}
			// Get configuration, either in the widget or the configuration
			
			if (is_array($instance) && array_key_exists('program', $instance) && (intVal($instance['program']) > 0)
					&& array_key_exists('destination', $instance) && !empty($instance['destination'])) {
				$program = intVal($instance['program']);
				// For Sub Ids, we take the global settings, then permit overriding 

				$widget_subs = array_intersect_key($instance, array_fill_keys(array('c1', 'c2', 'c3'), false)); // Array Fill Keys puts the sub values into the Key
				$widget_subs = array_diff($widget_subs, array('')); // Remove blanks
				// If subids are set, we'll pass them to dcom_get_bib_form for setting

				echo dcom_calculator_ad_code($program, $instance['destination'], $widget_subs);
			} else {
				echo "No Comparison Program Chosen";
			}
			echo $args['after_widget'];
		}


		// Manage Widgets
		public function form( $instance ) {
			$title = ! empty( $instance['title'] ) ? $instance['title'] : '';
			$destination_url = ! empty( $instance['destination'] ) ? $instance['destination'] : '';
			$program = !empty( $instance['program'] ) ? $instance['program'] : 4;
			$destination_text = __( 'Destination Url (full not relative)', 'dcom_bib' );
			$subids = array('c1' => 'Sub1', 'c2' => 'Sub2', 'c3' => 'Sub3');
		?>
			<p>
				<label for="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>"><?php _e( esc_attr( 'Title:' ) ); ?></label> 
				<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'title' ) ); ?>" type="text" value="<?php echo esc_attr( $title ); ?>">
			</p>

			<p>
				<label for="<?php echo esc_attr( $this->get_field_id( 'program' ) ); ?>"><?php _e( esc_attr( 'Comparison Option:' ) ); ?></label>
				<select class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'program' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'program' ) ); ?>">
		<?php foreach($this->program_options AS $program_id => $program_name) { ?>
					<option value="<?php echo $program_id; ?>"<?php if ($program == $program_id) { echo ' selected="selected"';} ?>><?php _e($program_name, 'dcom_bib'); ?></option>
		<?php } ?>
				</select>
			</p>
			<p>
				<label for="<?php echo esc_attr( $this->get_field_id( 'destination' ) ); ?>"><?php _e( esc_attr( 'Destination URL:' ) ); ?></label>
				<input required="required" class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'destination' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'destination' ) ); ?>" type="url" value="<?php echo esc_attr( $destination_url ); ?>" placeholder="<?php echo $destination_text;?>">
			</p>
		<?php
			foreach ($subids AS $subid => $display) {
				$curvalue = ! empty( $instance[$subid] ) ? $instance[$subid] : '';
		?>
			<p>
				<label for="<?php echo esc_attr( $this->get_field_id( $subid ) ); ?>"><?php _e( esc_attr( $display) ); ?>:</label>
				<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( $subid ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( $subid ) ); ?>" type="url" value="<?php echo esc_attr( $curvalue ); ?>">
			</p>
		<?php
			}
		}

		// Santitize Form Data
		public function update( $new_instance, $old_instance ) {
			$instance = array();
			$instance['title'] = ( ! empty( $new_instance['title'] ) ) ? strip_tags( $new_instance['title'] ) : '';
			$instance['program'] = ( ! empty( $new_instance['program'] ) ) ? strip_tags( $new_instance['program'] ) : '';
			$instance['destination'] = ( ! empty( $new_instance['destination'] ) ) ? strip_tags( $new_instance['destination'] ) : '';
			$subids = array('c1', 'c2', 'c3');
			foreach ($subids AS $subid)
				$instance[$subid] = ( ! empty( $new_instance[$subid] ) ) ? strip_tags( $new_instance[$subid] ) : '';
			return $instance;
		}
	}

	class Dcom_Ads_Widget extends Dcom_Ads_Calc_Base {
		function __construct() {
			parent::__construct(
				'dcom_ads_widget', // Base ID
				__( 'Debt.com Ads', 'dcom_bib' ), // Name
				array( 'description' => __( 'Debt.com Product Ads Widget', 'dcom_bib' ), ) // Args
			);

			$this->program_options = array(
				110 => __('Business Loans Ads', 'dcom_bib'),
				111 => __('Identity Theft Ads', 'dcom_bib'),
				111 => __('Personal Loans Ads', 'dcom_bib'),
				113 => __('Student Loan Ads', 'dcom_bib')
			);
		}

	}
	class Dcom_Calculator_Widget extends Dcom_Ads_Calc_Base {
		function __construct() {
			parent::__construct(
				'dcom_calculator_widget', // Base ID
				__( 'Debt.com Calculators', 'dcom_bib' ), // Name
				array( 'description' => __( 'Debt.com Calculators Widget', 'dcom_bib' ), ) // Args
			);

			$this->program_options = array(
				15 => __('Business Loans Calculator', 'dcom_bib'),
				5 => __('Personal Loans Calculator', 'dcom_bib'),
				69 => __('Student Loans Calculator', 'dcom_bib')
			);
		}
	}


	add_action('widgets_init', 'dcom_register_ads_calc_widget');
	function dcom_register_ads_calc_widget() {
		$prefix = '_dcom_bib_'; // Metabox Prefix
		$bib_configuration = get_option($prefix.'configuration');
		if (is_array($bib_configuration) && array_key_exists($prefix.'search_subid', $bib_configuration) && !empty($bib_configuration[$prefix.'search_subid'])) {	
			register_widget('Dcom_Ads_Widget');
			register_widget('Dcom_Calculator_Widget');
		}
	}