<?php
	class Dcom_Bib_Widget extends WP_Widget {
		function __construct() {
			parent::__construct(
				'dcom_bib_widget', // Base ID
				__( 'Debt.com Form', 'dcom_bib' ), // Name
				array( 'description' => __( 'Debt.com Lead Form', 'dcom_bib' ), ) // Args
			);
		}
		// Draw Widgets
		public function widget( $args, $instance ) {
			$prefix = '_dcom_bib_'; // Metabox Prefix
			$wrap_class = !empty($instance['wrap_class']) ? $instance['wrap_class'] : '';
			if ($wrap_class) { echo '<div class="'.$wrap_class.'">'; }
			echo $args['before_widget'];

			// Show Title if assigned
			if ( ! empty( $instance['title'] ) ) {
				echo $args['before_title'] . apply_filters( 'widget_title', $instance['title'] ) . $args['after_title'];
			}

			// Get configuration, either in the widget or the configuration
			$configuration_url = false;
			
			if ( is_array($instance) && array_key_exists('configuration_url', $instance) && !empty($instance['configuration_url']) ) {
				$configuration_url = $instance['configuration_url'];
			} else {
				$bib_configuration = get_option($prefix.'configuration');
				if (is_array($bib_configuration) && array_key_exists($prefix.'configuration_url', $bib_configuration) && !empty($bib_configuration[$prefix.'configuration_url'])) {
					// Have a global config
					$configuration_url = $bib_configuration[$prefix.'configuration_url'];
				}
			}

			// For Sub Ids, we take the global settings, then permit overriding 
			$global_subs = array('s3' => rwmb_meta($prefix.'sub1'), 's4' => rwmb_meta($prefix.'sub2'), 's5' => rwmb_meta($prefix.'sub3'));
			$global_subs = array_diff($global_subs, array('')); // Remove blanks
			$widget_subs = array_intersect_key($instance, array_fill_keys(array('s3', 's4', 's5'), false)); // Array Fill Keys puts the sub values into the Key
			$widget_subs = array_diff($widget_subs, array('')); // Remove blanks
			// If subids are set, we'll pass them to dcom_get_bib_form for setting
			$extra_params = array_merge($global_subs, $widget_subs); // Override Global with Widget ones
			$extra_params['s2'] = 'BIBPlugin';

			if ($configuration_url) {
				echo dcom_get_bib_form($configuration_url, $extra_params);
			}

			echo $args['after_widget'];
			if ($wrap_class) { echo '</div>'; }
		}

		// Manage Widgets
		public function form( $instance ) {
			$title = ! empty( $instance['title'] ) ? $instance['title'] : '';
			$wrap_class = !empty($instance['wrap_class']) ? $instance['wrap_class'] : '';
			$configuration_url = ! empty( $instance['configuration_url'] ) ? $instance['configuration_url'] : '';
			$configuration_text = __( 'Override Url (normally blank)', 'dcom_bib' );
			$subids = array('s3' => 'Sub1', 's4' => 'Sub2', 's5' => 'Sub3');
		?>
			<p>
				<label for="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>"><?php _e( esc_attr( 'Title:' ) ); ?></label> 
				<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'title' ) ); ?>" type="text" value="<?php echo esc_attr( $title ); ?>">
			</p>
		<?php foreach ($subids AS $subid => $display) {
				$curvalue = ! empty( $instance[$subid] ) ? $instance[$subid] : ''; ?>
			<p>
				<label for="<?php echo esc_attr( $this->get_field_id( $subid ) ); ?>"><?php _e( esc_attr( $display) ); ?>:</label>
				<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( $subid ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( $subid ) ); ?>" type="url" value="<?php echo esc_attr( $curvalue ); ?>">
			</p>
		<?php } ?>
			<p>
				<label for="<?php echo esc_attr( $this->get_field_id( 'wrap_class' ) ); ?>"><?php _e( esc_attr( 'Wrapper DIV Class:' ) ); ?></label> 
				<input class="widefat" placeholder="dcom-bib-non-mobile" id="<?php echo esc_attr( $this->get_field_id( 'wrap_class' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'wrap_class' ) ); ?>" type="text" value="<?php echo esc_attr( $wrap_class ); ?>">
			</p>
			<p>
				<label for="<?php echo esc_attr( $this->get_field_id( 'configuration_url' ) ); ?>"><?php _e( esc_attr( 'Configuration URL:' ) ); ?></label>
				<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'configuration_url' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'configuration_url' ) ); ?>" type="url" value="<?php echo esc_attr( $configuration_url ); ?>" placeholder="<?php echo $configuration_text;?>">
			</p>
		<?php 
		}

		// Santitize Form Data
		public function update( $new_instance, $old_instance ) {
			$instance = array();
			$instance['title'] = ( ! empty( $new_instance['title'] ) ) ? strip_tags( $new_instance['title'] ) : '';
			$instance['configuration_url'] = ( ! empty( $new_instance['configuration_url'] ) ) ? strip_tags( $new_instance['configuration_url'] ) : '';
			$instance['wrap_class'] = ( ! empty( $new_instance['wrap_class'] ) ) ? strip_tags( $new_instance['wrap_class'] ) : '';
			$subids = array('s3', 's4', 's5');
			foreach ($subids AS $subid)
				$instance[$subid] = ( ! empty( $new_instance[$subid] ) ) ? strip_tags( $new_instance[$subid] ) : '';
			return $instance;
		}
	}

	add_action('widgets_init', 'dcom_register_bib_widget');

	function dcom_register_bib_widget() {
		$prefix = '_dcom_bib_'; // Metabox Prefix
		$bib_configuration = get_option($prefix.'configuration');
		if (is_array($bib_configuration) && array_key_exists($prefix.'configuration_url', $bib_configuration) && !empty($bib_configuration[$prefix.'configuration_url'])) {	
			register_widget('Dcom_Bib_Widget');
		}
	}