<?php
	class Dcom_Phone_Widget extends WP_Widget {
		function __construct() {
			parent::__construct(
				'dcom_phone_widget', // Base ID
				__( 'Debt.com Phone', 'dcom_bib' ), // Name
				array( 'description' => __( 'Debt.com Phone Widget', 'dcom_bib' ), ) // Args
			);
		}
		// Draw Widgets
		public function widget( $args, $instance ) {
			$prefix = '_dcom_bib_'; // Metabox Prefix
			$wrap_class = !empty($instance['wrap_class']) ? $instance['wrap_class'] : '';

			if ($wrap_class) { echo '<div class="'.$wrap_class.'">'; }
			echo $args['before_widget'];

			// Show Title if assigned
			if ( ! empty( $instance['title'] ) ) {
				echo $args['before_title'] . apply_filters( 'widget_title', $instance['title'] ) . $args['after_title'];
			}

			// Get configuration, either in the widget or the configuration
			$configuration_url = '';
			if ( is_array($instance) && array_key_exists('configuration_url', $instance) && !empty($instance['configuration_url']) ) {
				$configuration_url = $instance['configuration_url'];
			}
			echo dcom_get_bib_phone($configuration_url);

			echo $args['after_widget'];
			if ($wrap_class) { echo '</div>'; }
		}

		// Manage Widgets
		public function form( $instance ) {
			$title = ! empty( $instance['title'] ) ? $instance['title'] : '';
			$configuration_url = ! empty( $instance['configuration_url'] ) ? $instance['configuration_url'] : '';
			$configuration_text = __( 'Override Url (normally blank)', 'dcom_bib' );
			$wrap_class = !empty($instance['wrap_class']) ? $instance['wrap_class'] : '';
		?>
			<p>
				<label for="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>"><?php _e( esc_attr( 'Title:' ) ); ?></label> 
				<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'title' ) ); ?>" type="text" value="<?php echo esc_attr( $title ); ?>">
			</p>
			<p>
				<label for="<?php echo esc_attr( $this->get_field_id( 'wrap_class' ) ); ?>"><?php _e( esc_attr( 'Wrapper DIV Class:' ) ); ?></label> 
				<input class="widefat" placeholder="dcom-bib-mobile-only" id="<?php echo esc_attr( $this->get_field_id( 'wrap_class' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'wrap_class' ) ); ?>" type="text" value="<?php echo esc_attr( $wrap_class ); ?>">
			</p>
			<p>
				<label for="<?php echo esc_attr( $this->get_field_id( 'configuration_url' ) ); ?>"><?php _e( esc_attr( 'Configuration URL:' ) ); ?></label>
				<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'configuration_url' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'configuration_url' ) ); ?>" type="url" value="<?php echo esc_attr( $configuration_url ); ?>" placeholder="<?php echo $configuration_text;?>">
			</p>
		<?php
		}

		// Santitize Form Data
		public function update( $new_instance, $old_instance ) {
			$instance = array();
			$instance['title'] = ( ! empty( $new_instance['title'] ) ) ? strip_tags( $new_instance['title'] ) : '';
			$instance['wrap_class'] = ( ! empty( $new_instance['wrap_class'] ) ) ? strip_tags( $new_instance['wrap_class'] ) : '';
			$instance['configuration_url'] = ( ! empty( $new_instance['configuration_url'] ) ) ? strip_tags( $new_instance['configuration_url'] ) : '';
			return $instance;
		}
	}

	add_action('widgets_init', 'dcom_register_phone_widget');

	function dcom_register_phone_widget() {
		$prefix = '_dcom_bib_'; // Metabox Prefix
		$bib_configuration = get_option($prefix.'configuration');
		if (is_array($bib_configuration) && array_key_exists($prefix.'configuration_url', $bib_configuration) && !empty($bib_configuration[$prefix.'configuration_url'])) {	
			register_widget('Dcom_Phone_Widget');
		}
	}
