<?php
	class Dcom_Comparison_Widget extends WP_Widget {
		function __construct() {
			parent::__construct(
				'dcom_comparison_widget', // Base ID
				__( 'Debt.com Comparison', 'dcom_bib' ), // Name
				array( 'description' => __( 'Debt.com Product Comparison Widget', 'dcom_bib' ), ) // Args
			);
		}
		// Draw Widgets
		public function widget( $args, $instance ) {
			echo $args['before_widget'];

			// Show Title if assigned
			if ( ! empty( $instance['title'] ) ) {
				echo $args['before_title'] . apply_filters( 'widget_title', $instance['title'] ) . $args['after_title'];
			}
			// Get configuration, either in the widget or the configuration
			
			if (is_array($instance) && array_key_exists('program', $instance) && (intVal($instance['program']) > 0) ) {
				$program = intVal($instance['program']);
				// For Sub Ids, we take the global settings, then permit overriding 

				$widget_subs = array_intersect_key($instance, array_fill_keys(array('c1', 'c2', 'c3'), false)); // Array Fill Keys puts the sub values into the Key
				$widget_subs = array_diff($widget_subs, array('')); // Remove blanks
				// If subids are set, we'll pass them to dcom_get_bib_form for setting

				echo dcom_comparison_code($program, $widget_subs);
			} else {
				echo "No Comparison Program Chosen";
			}
			echo $args['after_widget'];
		}


		// Manage Widgets
		public function form( $instance ) {
			$title = ! empty( $instance['title'] ) ? $instance['title'] : '';

			$program = !empty( $instance['program'] ) ? $instance['program'] : 4;
			$configuration_text = __( 'Override Url (normally blank)', 'dcom_bib' );
			$subids = array('c1' => 'Sub1', 'c2' => 'Sub2', 'c3' => 'Sub3');
			$program_options = array(
				4	=> __('Personal Loans Comparison', 'dcom_bib'),
				17	=> __('Business Loans Comparison', 'dcom_bib'),
				70	=> __('Student Loan Comparison', 'dcom_bib'),
				76	=> __('Identity Theft Comparison', 'dcom_bib')
			);
		?>
			<p>
				<label for="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>"><?php _e( esc_attr( 'Title:' ) ); ?></label> 
				<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'title' ) ); ?>" type="text" value="<?php echo esc_attr( $title ); ?>">
			</p>

			<p>
				<label for="<?php echo esc_attr( $this->get_field_id( 'program' ) ); ?>"><?php _e( esc_attr( 'Comparison Option:' ) ); ?></label>
				<select class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'program' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'program' ) ); ?>">
		<?php foreach($program_options AS $program_id => $program_name) { ?>
					<option value="<?php echo $program_id; ?>"<?php if ($program == $program_id) { echo ' selected="selected"';} ?>><?php _e($program_name, 'dcom_bib'); ?></option>
		<?php } ?>
				</select>
			</p>
		<?php
			foreach ($subids AS $subid => $display) {
				$curvalue = ! empty( $instance[$subid] ) ? $instance[$subid] : '';
		?>
			<p>
				<label for="<?php echo esc_attr( $this->get_field_id( $subid ) ); ?>"><?php _e( esc_attr( $display) ); ?>:</label>
				<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( $subid ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( $subid ) ); ?>" type="url" value="<?php echo esc_attr( $curvalue ); ?>">
			</p>
		<?php
			}
		}

		// Santitize Form Data
		public function update( $new_instance, $old_instance ) {
			$instance = array();
			$instance['title'] = ( ! empty( $new_instance['title'] ) ) ? strip_tags( $new_instance['title'] ) : '';
			$instance['program'] = ( ! empty( $new_instance['program'] ) ) ? strip_tags( $new_instance['program'] ) : '';
			$subids = array('c1', 'c2', 'c3');
			foreach ($subids AS $subid)
				$instance[$subid] = ( ! empty( $new_instance[$subid] ) ) ? strip_tags( $new_instance[$subid] ) : '';
			return $instance;
		}
	}

	add_action('widgets_init', 'dcom_register_comparison_widget');
	function dcom_register_comparison_widget() {
		$prefix = '_dcom_bib_'; // Metabox Prefix
		$bib_configuration = get_option($prefix.'configuration');
		if (is_array($bib_configuration) && array_key_exists($prefix.'search_subid', $bib_configuration) && !empty($bib_configuration[$prefix.'search_subid'])) {	
			register_widget('Dcom_Comparison_Widget');
		}
	}
